@@ -2,7 +2,7 @@ package Plack::App::ServiceStatus;
 
 # ABSTRACT: Check and report status of various services needed by your app
 
-our $VERSION = '0.911'; # VERSION
+our $VERSION = '0.912'; # VERSION
 
 use 5.024;
 use strict;
@@ -137,7 +137,7 @@ Plack::App::ServiceStatus - Check and report status of various services needed b
 
 =head1 VERSION
 
-version 0.911
+version 0.912
 
 =head1 SYNOPSIS
 
@@ -150,7 +150,7 @@ version 0.911
       version       => '1.42',
       DBIC          => [ $schema, 'select 1' ],
       Elasticsearch => $es, # instance of Search::Elasticsearch
-  );
+  )->to_app;
 
   builder {
     mount "/_status" => $status_app;
@@ -166,6 +166,7 @@ version 0.911
           '+MyApp::ServiceStatus' => {
                 foo => literal("foo")
           },
+          buildinfo => literal('buildinfo.json'),
       );
       route '/some/endpoint' => 'some_controller.some_action';
       # ...
